Описание
--------
Самый простой способ записи данных в платформу Пересвет_ - через команду API `data/set`_.

.. _Пересвет: https://github.com/mp-co-ru/peresvet

.. _data/set: https://mp-co-ru.github.io/peresvet/data_api.html#tags_app_api_svc.data_set

Но в этом случае придётся самостоятельно заботиться о буферизации данных,
о событиях изменения паратров тегов и т.д.

Всю эту работу берёт на себя коннектор - специализированная программа,
умеющая забирать данные из какого-либо источника и отправлять их в платформу.

Рекомендации по созданию коннекторов:

#. Для каждого протокола данных (Modbus, OPC и т.д.) - отдельный коннектор.
#. Коннектор работает только с одним источником данных.
